@@ -27,6 +27,7 @@ sub _http_request{
         my $cb = pop;
         $self->ua->$method(@_,sub{
             my($ua,$tx) = @_;
+            $self->save_cookie();
             if(defined $tx and $tx->success){
                 my $r = eval{$opt{json}?$tx->res->json:$tx->res->body;};
                 if($@){
@@ -41,6 +42,7 @@ sub _http_request{
     else{
         for(my $i=0;$i<=$opt{retry_times};$i++){
             my $tx = $self->ua->$method(@_);
+            $self->save_cookie();
             if(defined $tx and $tx->success){
                 my $r = eval{$opt{json}?$tx->res->json:$tx->res->body;};
                 if($@){
@@ -56,6 +58,30 @@ sub _http_request{
     }
 }
 
+sub load_cookie{
+    my $self = shift;
+    return if not $self->keep_cookie;
+    return if not defined $self->qq;
+    my $cookie_jar;
+    my $cookie_path = $self->cookie_dir . '/mojo_webqq_cookie_' . $self->qq . '.dat';
+    return if not -f $cookie_path;
+    eval{require Storable;$cookie_jar = Storable::retrieve($cookie_path)};
+    if($@){
+        $self->warn("客户端加载cookie失败: $@");
+        return;
+    }
+    $self->ua->cookie_jar($cookie_jar);
+
+}
+sub save_cookie{
+    my $self = shift;
+    return if not $self->keep_cookie;
+    return if not defined $self->qq;
+    my $cookie_path = $self->cookie_dir . '/mojo_webqq_cookie_' . $self->qq . '.dat';
+    eval{Storable::nstore($self->ua->cookie_jar,$cookie_path);};
+    $self->warn("客户端保存cookie失败: $@") if $@;
+}
+
 sub search_cookie{
     my $self   = shift;
     my $cookie = shift;
